@@ -21,7 +21,6 @@ from bomiot_message import permission_message_return, detail_message_return, msg
 from django.contrib.auth import get_user_model
 from django.db.models import Q
 from django.conf import settings
-from django.core.cache import cache
 
 User = get_user_model()
 
@@ -815,167 +814,3 @@ class DepartmentDelete(viewsets.ModelViewSet):
                     models.Department.objects.filter(id=data.get('id')).update(is_delete=True)
         return Response(msg_message_return(self.request.META.get('HTTP_LANGUAGE', ''),
                                            "Success delete department"), status=200)
-
-
-class APIList(viewsets.ModelViewSet):
-    """
-        list:
-            Response a api data list（all）
-    """
-    pagination_class = APIPageNumberPagination
-    permission_classes = [NormalPermission, ]
-    filter_backends = [DjangoFilterBackend, OrderingFilter, ]
-    ordering_fields = ['id', "api", "func_name", "created_time", "updated_time", ]
-    filter_class = filter.APIFilter
-
-    def get_queryset(self):
-        if self.request.user:
-            query_data = {'is_delete': False}
-            search = self.request.query_params.get('search')
-            if search:
-                query_data['api__icontains'] = search
-            return models.API.objects.filter(**query_data).order_by('id')
-        else:
-            return models.API.objects.none()
-
-    def get_serializer_class(self):
-        if self.action in ['list']:
-            return serializers.APISerializer
-        else:
-            raise MethodNotAllowed(self.request.method)
-            
-    def list(self, request, *args, **kwargs):
-        return super().list(request, *args, **kwargs)
-
-
-class APIChange(viewsets.ModelViewSet):
-    """
-        create:
-            Change one API
-    """
-    permission_classes = [NormalPermission, ]
-    filter_backends = [DjangoFilterBackend, OrderingFilter, ]
-    ordering_fields = ['id', "created_time", "updated_time", ]
-    filter_class = filter.APIFilter
-
-    def get_serializer_class(self):
-        if self.action in ['create']:
-            return serializers.APISerializer
-        else:
-            raise MethodNotAllowed(self.request.method)
-
-    def create(self, request, **kwargs):
-        data = self.request.data
-        data_check = bool(re.search(r'\s', data))
-        if data_check is True:
-            raise APIException(detail_message_return(self.request.META.get('HTTP_LANGUAGE', ''),
-                                                     "API name can not contain space"))
-        department_check = models.API.objects.filter(func_name=data.get('func_name'), is_delete=False)
-        if department_check.exists():
-            raise APIException(detail_message_return(self.request.META.get('HTTP_LANGUAGE', ''),
-                                                     "API exists"))
-        else:
-            
-            if self.request.auth.is_superuser is True:
-                models.API.objects.filter(id=data.get('id')).update(func_name=data.get('func_name'))
-            else:
-                raise APIException(detail_message_return(self.request.META.get('HTTP_LANGUAGE', ''),
-                                                             "User does not have permission to change API"))
-        return Response(msg_message_return(self.request.META.get('HTTP_LANGUAGE', ''),
-                                           "Success change API"), status=200)
-
-
-class PyPiList(viewsets.ModelViewSet):
-    """
-        list:
-            Response a PyPi data list（all）
-    """
-    permission_classes = [NormalPermission, ]
-    filter_backends = [DjangoFilterBackend, OrderingFilter, ]
-    ordering_fields = ["id", "created_time", "updated_time", ]
-    filter_class = filter.PyPiFilter
-
-    def get_queryset(self):
-        if self.request.user:
-            query_data = {}
-            query_data['is_delete'] = False
-            query_data['category__icontains'] = self.request.query_params.get('search')
-            return models.PyPi.objects.filter(**query_data).order_by('-date')
-        else:
-            return models.PyPi.objects.none()
-
-    def get_serializer_class(self):
-        if self.action in ['list']:
-            return serializers.PyPiSerializer
-        else:
-            raise MethodNotAllowed(self.request.method)
-        
-    def list(self, request, *args, **kwargs):
-        return super().list(request, *args, **kwargs)
-
-
-class PyPiChartsPage(CorePageNumberPagination):
-    def __init__(self, *args, **kwargs):
-        self.pypi_data = {}
-        self.pypi_data['title'] = 'Bomiot PyPi Downloads Pie Chart'
-        self.pypi_data['xAxis_list'] = []
-        self.with_mirrors_list = []
-        self.without_mirrors_list = []
-        super(PyPiChartsPage, self).__init__(*args, **kwargs)
-    
-    def get_pypi_return_data(self, data) -> dict:
-        date_check = data.date.strftime("%m-%d")
-        if date_check in self.pypi_data['xAxis_list']:
-            return data
-        else:
-            self.pypi_data['xAxis_list'].append(date_check)
-            with_mirrors_check =  models.PyPi.objects.filter(category='with_mirrors', date=data.date)
-            without_mirrors_check =  models.PyPi.objects.filter(category='without_mirrors', date=data.date)
-            if with_mirrors_check.exists():
-                self.with_mirrors_list.append(with_mirrors_check.first().downloads)
-            else:
-                self.with_mirrors_list.append(0)
-            if without_mirrors_check.exists():
-                self.without_mirrors_list.append(without_mirrors_check.first().downloads)
-            else:
-                self.without_mirrors_list.append(0)
-        return data
-
-    def query_data_add(self) -> list:
-        pypi_list = models.PyPi.objects.filter().order_by('-date')[:90]
-        pypi_data_list = list(map(lambda data: self.get_pypi_return_data(data), pypi_list))
-
-        self.pypi_data['xAxis_list'] = list(reversed(self.pypi_data['xAxis_list']))
-        self.pypi_data['series_list'] = [
-            { 'name': "with_mirrors", 'data': list(reversed(self.with_mirrors_list)) },
-            { 'name': "without_mirrors", 'data': list(reversed(self.without_mirrors_list)) }
-        ]
-
-        return [
-            ("pypi_data", self.pypi_data),
-        ]
-
-
-class PyPiCharts(viewsets.ModelViewSet):
-    """
-        list:
-            Response a PID Charts data list（all）
-    """
-    pagination_class = PyPiChartsPage
-    permission_classes = [NormalPermission, ]
-    filter_backends = [DjangoFilterBackend, OrderingFilter, ]
-    ordering_fields = ["id", "created_time", "updated_time", ]
-    filter_class = filter.PyPiFilter
-
-    def get_queryset(self):
-        return models.PyPi.objects.none()
-
-    def get_serializer_class(self):
-        if self.action in ['list']:
-            return serializers.PyPiSerializer
-        else:
-            raise MethodNotAllowed(self.request.method)
-        
-    def list(self, request, *args, **kwargs):
-        return super().list(request, *args, **kwargs)
-
