@@ -1,22 +1,28 @@
 import json, orjson
 import mimetypes
 import os
+import glob
+import aiofiles
 from django.conf import settings
-from django.http import JsonResponse, HttpResponse, FileResponse
+from django.http import JsonResponse, HttpResponse, FileResponse, StreamingHttpResponse
 from wsgiref.util import FileWrapper
-from configparser import ConfigParser
+from django.views.generic import TemplateView
 from django.contrib.auth import authenticate, login, logout
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth import get_user_model
 from django.core.cache import cache
+from django.shortcuts import render
 from bomiot.server.core.jwt_auth import create_token, parse_payload
 from bomiot.server.core.models import Permission
 from bomiot_message import login_message_return, others_message_return
 from bomiot.server.server.pkgcheck import url_ignore
-from os.path import join, isdir, exists
+from os.path import join, isdir, exists, isfile
 from os import listdir
 import importlib.util
+from configparser import ConfigParser
 from pathlib import Path
+from bomiot.cmd.copyfile import copy_files
+from bomiot.server.core.utils import are_folders_identical
 from django.urls import get_resolver, URLPattern, URLResolver
 
 User = get_user_model()
@@ -25,6 +31,31 @@ async def test(request):
     return JsonResponse({"msg": "This is Django API"})
 
 
+class IndexTemplateView(TemplateView):
+    def get_template_names(self):
+        project_name = self.request.COOKIES.get('project', settings.PROJECT_NAME)
+        if project_name.lower() == 'bomiot':
+            template_path = join(settings.WORKING_SPACE, settings.PROJECT_NAME, 'templates/dist/spa/index.html')
+        else:
+            if project_name == settings.PROJECT_NAME:
+                template_path = join(settings.WORKING_SPACE, settings.PROJECT_NAME, 'templates/dist/spa/index.html')
+            else:
+                project_template = join(settings.WORKING_SPACE, project_name, 'templates')
+                working_template = join(settings.WORKING_SPACE, settings.PROJECT_NAME, 'templates', 'project', project_name)
+                if exists(working_template):
+                    while True:
+                        template_mirror = are_folders_identical(project_template, working_template)
+                        if template_mirror is True:
+                            break
+                        else:
+                            continue
+                else:
+                    os.makedirs(working_template)
+                    copy_files(project_template, working_template)
+                template_path = join(working_template, 'dist/spa/index.html')
+        return [template_path]
+
+
 def logins(request):
     data = json.loads(request.body.decode().replace("'", '"'))
     user_check = User.objects.filter(username=data.get('username'), is_delete=False)
@@ -62,7 +93,7 @@ def logins(request):
 
 
 @login_required
-def logouts(request):
+async def logouts(request):
     if request.user.is_authenticated:
         logout(request)
         return JsonResponse({'msg': others_message_return(request.META.get('HTTP_LANGUAGE', ''), 'Welcome Back Again')})
@@ -70,17 +101,21 @@ def logouts(request):
         return JsonResponse(login_message_return(request.META.get('HTTP_LANGUAGE', ''), 'User Not Log In'))
 
 
-def check_token(request):
+async def check_token(request):
     token = request.META.get('HTTP_TOKEN')
     context = parse_payload(token)
     return JsonResponse(context)
 
 
-def mdurl(request, mddocs):
+async def mdurl(request, mddocs):
+    project_name = request.COOKIES.get('project', settings.PROJECT_NAME)
     language = request.META.get('HTTP_LANUAGE', '')
     if not mddocs.endswith('.md'):
         return JsonResponse({'detail': others_message_return(language, 'Only support markdown file')})
-    folder_path = Path(settings.MEDIA_ROOT)
+    if project_name.lower() == 'bomiot':
+        folder_path = Path(settings.MEDIA_ROOT)
+    else:
+        folder_path = Path(join(settings.WORKING_SPACE, project_name, 'media'))
     all_files = [f.name for f in folder_path.iterdir() if f.is_file()]
     start_words = mddocs.split('.')
     md_check_list_all = []
@@ -92,46 +127,64 @@ def mdurl(request, mddocs):
             if i.startswith(start_words[0]) and i.endswith('.md'):
                 md_check_list_all.append(i)
     if len(md_check_list_only) == 1:
-        return HttpResponse(f"media/{mddocs}")
+        async def file_iterator():
+            async with aiofiles.open(join(settings.MEDIA_ROOT, mddocs), 'rb') as f:
+                while chunk := await f.read(8192):
+                    yield chunk
+        response = StreamingHttpResponse(file_iterator())
+        response['Cache-Control'] = 'no-store, no-cache, must-revalidate, max-age=0'
+        response['Pragma'] = 'no-cache'
+        response['Expires'] = '0'
+        return response
     else:
         if len(md_check_list_all) == 0:
             return JsonResponse({'detail': others_message_return(language, 'Markdown file not found')})
-        return HttpResponse(f"media/{md_check_list_all[0]}")
-    
+        async def file_iterator():
+            async with aiofiles.open(join(settings.MEDIA_ROOT, mddocs), 'rb') as f:
+                while chunk := await f.read(8192):
+                    yield chunk
+        response = StreamingHttpResponse(file_iterator())
+        response['Cache-Control'] = 'no-store, no-cache, must-revalidate, max-age=0'
+        response['Pragma'] = 'no-cache'
+        response['Expires'] = '0'
+        return response
 
 def favicon(request):
-    path = join(settings.MEDIA_ROOT, 'img', 'logo.png')
+    project_name = request.COOKIES.get('project', settings.PROJECT_NAME)
+    if project_name.lower() == 'bomiot':
+        path = join(settings.MEDIA_ROOT, 'img', 'logo.png')
+    else:
+        if project_name == settings.PROJECT_NAME:
+            path = join(settings.MEDIA_ROOT, 'img', 'logo.png')
+        else:
+            path = join(settings.WORKING_SPACE, project_name, 'media', 'img', 'logo.png')
     resp = FileResponse(open(path, 'rb'))
     resp['Cache-Control'] = 'max-age=864000000000'
     return resp
 
-
 def statics(request):
-    if cache.has_key("templates_path") is False:
-            CONFIG = ConfigParser()
-            CONFIG.read(join(settings.WORKING_SPACE, 'setup.ini'), encoding='utf-8')
-            templates_path = CONFIG.get('templates', 'name', fallback='templates/dist/spa/index.html')
-            cache.set("templates_path", templates_path)
+    project_name = request.COOKIES.get('project', settings.PROJECT_NAME)
+    if project_name.lower() == 'bomiot':
+        base_dir = join(settings.WORKING_SPACE, settings.PROJECT_NAME, 'templates', 'dist', 'spa')
     else:
-        templates_path = cache.get("templates_path")
-    path = join(settings.WORKING_SPACE, settings.PROJECT_NAME)
-    static_path_split = templates_path.split('/')[:-1]
-    for i in static_path_split:
-        if i == '':
-            continue
+        if project_name == settings.PROJECT_NAME:
+            base_dir = join(settings.WORKING_SPACE, settings.PROJECT_NAME, 'templates', 'dist', 'spa')
         else:
-            path = join(path, i)
-    request_path = request.path_info.split('/')
-    for j in request_path:
-        if j == '':
-            continue
-        else:
-            path = join(path, j)
-    resp = FileResponse(open(path, 'rb'))
-    resp['Cache-Control'] = 'max-age=864000000000'
-    return resp
+            base_dir = join(settings.WORKING_SPACE, settings.PROJECT_NAME, 'templates', 'project', project_name, 'dist', 'spa')
+    path = join(base_dir, request.path_info.lstrip('/'))
+    if exists(path) and isfile(path):
+        resp = FileResponse(open(path, 'rb'))
+        resp['Cache-Control'] = 'max-age=864000000000'
+        return resp
+    pattern = join(base_dir, '**', 'index-*.js')
+    index_js_files = glob.glob(pattern, recursive=True)
+    if index_js_files:
+        fallback_path = index_js_files[0]
+        resp = FileResponse(open(fallback_path, 'rb'))
+        resp['Cache-Control'] = 'max-age=864000000000'
+        return resp
 
-def google(request):
+async def google(request):
     return JsonResponse({})
 
 def queryset_to_json(queryset):
@@ -183,4 +236,32 @@ def init_permission():
             Permission.objects.bulk_create(perm_objs, batch_size=200)
         User.objects.bulk_update(user_objs, ['permission'], batch_size=100)
     except Exception as e:
-        print(f"Error initializing permissions: {e}")
\ No newline at end of file
+        print(f"Error initializing permissions: {e}")
+
+def init_bomiot():
+    import socket, webbrowser
+    try:
+        User.objects.get(username='admin', is_superuser=True)
+        print('Admin user already exists, you can use admin to login:')
+    except:
+        username = 'admin'
+        email = f'{username}@bomiot.com'
+        password = username
+        admin, created = User.objects.update_or_create(email=email, username=username)
+        admin.set_password(password)
+        admin.is_active = True
+        admin.is_superuser = True
+        admin.is_staff = True
+        admin.save()
+        print('%s admin account: %s(%s), initial password: %s, just use it temporarily '
+              'and change the password for safety' % \
+              ('Created' if created else 'Reset', username, email, password))
+    print('系统启动成功')
+    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    s.connect(('8.8.8.8', 80))
+    ip = s.getsockname()[0]
+    print('本机IP地址为:', ip)
+    s.close()
+    baseurl = "http://" + ip + ":8008"
+    print('浏览器正在打开:', baseurl)
+    webbrowser.open(baseurl)
\ No newline at end of file
