@@ -6,7 +6,7 @@ const progress = true;
 const multiLine = true;
 const group = true;
 const classes = 'flat';
-const timeout = 2000;
+const timeout = 3000;
 
 export default boot(async (/* { app, router, ... } */) => {
   Notify.registerType('success', {
@@ -16,12 +16,12 @@ export default boot(async (/* { app, router, ... } */) => {
     multiLine: multiLine,
     group: group,
     color: 'positive',
-    textColor: 'white',
+    textColor: 'black',
     classes: classes,
     timeout: timeout
   })
   Notify.registerType('error', {
-    icon: 'bug_report',
+    icon: 'warning',
     position: position,
     progress: progress,
     multiLine: multiLine,
@@ -32,7 +32,7 @@ export default boot(async (/* { app, router, ... } */) => {
     timeout: timeout
   })
     Notify.registerType('warning', {
-    icon: 'warning',
+    icon: 'privacy_tip',
     position: position,
     progress: progress,
     multiLine: multiLine,
@@ -43,13 +43,13 @@ export default boot(async (/* { app, router, ... } */) => {
     timeout: timeout
   })
     Notify.registerType('info', {
-    icon: 'contact_support',
+    icon: 'privacy_tip',
     position: position,
     progress: progress,
     multiLine: multiLine,
     group: group,
     color: 'info',
-    textColor: 'white',
+    textColor: 'black',
     classes: classes,
     timeout: timeout
   })
